
HTTP request methods
-------

**Description:**

HTTP offers a number of methods that can be used to perform actions on the web server. 
Many of these methods are designed to aid developers in deploying and testing 
HTTP applications. These HTTP methods can be used for nefarious purposes if the web 
server is misconfigured.


**Solution:**

Verify that the application accepts only a defined set of HTTP request methods, such as 
GET and POST and unused methods are explicitly blocked/disabled.
	
